@@ -24,10 +24,12 @@
 #' n <- 200
 #' sig <- 2
 #' dat <- gamSim(1, n = n, scale = sig, verbose = FALSE)
-#' dat$x4 <- as.factor(c(rep("A", 50), rep("B", 50), rep("C", 50),
-#'                     rep("D", 50)))
+#' dat$x4 <- as.factor(c(
+#'   rep("A", 50), rep("B", 50), rep("C", 50),
+#'   rep("D", 50)
+#' ))
 #' fit_gam <- gam(y ~ s(x0) + s(I(x1^2)) + s(x2) +
-#'                offset(x3) + x4, data = dat) # fit model
+#'   offset(x3) + x4, data = dat) # fit model
 #'
 #' tmp <- plot(fit_gam, pages = 1) # plot output
 #' tmp <- no_plot(fit_gam) # no plot output
@@ -65,10 +67,12 @@ no_plot <- function(model = NULL) {
 #' n <- 200
 #' sig <- 2
 #' dat <- gamSim(1, n = n, scale = sig, verbose = FALSE)
-#' dat$x4 <- as.factor(c(rep("A", 50), rep("B", 50), rep("C", 50),
-#'                     rep("D", 50)))
+#' dat$x4 <- as.factor(c(
+#'   rep("A", 50), rep("B", 50), rep("C", 50),
+#'   rep("D", 50)
+#' ))
 #' fit_gam <- gam(y ~ s(x0) + s(I(x1^2)) + s(x2) +
-#'                offset(x3) + x4, data = dat) # fit model
+#'   offset(x3) + x4, data = dat) # fit model
 #'
 #' tmp <- gam_to_df(fit_gam, "x2")
 #' @export
@@ -80,9 +84,11 @@ gam_to_df <- function(model = NULL, pred = NULL) {
   # get list index of spec. predictor
   set_pred <- which(grepl(pred, plot_df))
 
-  df <- data.frame(x = plot_df[[set_pred]]$x,
-                   se_upr = plot_df[[set_pred]]$fit + plot_df[[set_pred]]$se,
-                   se_lwr = plot_df[[set_pred]]$fit - plot_df[[set_pred]]$se,
-                   y = plot_df[[set_pred]]$fit)
+  df <- tibble(
+    x = plot_df[[set_pred]]$x,
+    se_upr = plot_df[[set_pred]]$fit + plot_df[[set_pred]]$se,
+    se_lwr = plot_df[[set_pred]]$fit - plot_df[[set_pred]]$se,
+    y = plot_df[[set_pred]]$fit
+  )
   return(df)
 }
