@@ -2,45 +2,35 @@
 #' @title Calculate odds ratios of Generalized Additive (Mixed) Models
 #'
 #' @importFrom stats coefficients predict
+#' @importFrom tibble tibble
 #'
 #' @description This function calculates odds ratio(s) for specific increment
-#'     steps of a GAM(M)s.
-#' @description Odds ratios can also be calculated for continuous percentage
-#' increment steps across the whole predictor distribution using `slice = TRUE`.
+#'   steps of a GAM(M)s. Odds ratios can also be calculated for continuous
+#'   percentage increment steps across the whole predictor distribution using
+#'   `slice = TRUE`.
 #'
 #' @param data The data used for model fitting.
-#'
 #' @param model A fitted GAM(M).
+#' @param pred Character. Predictor name for which to calculate the odds ratio.
+#' @param values Numeric vector of length two. Predictor values to estimate odds
+#'   ratio from. Function is written to use the first provided value as the
+#'   "lower" one, i.e. calculating the odds ratio 'from value1 to value2'. Only
+#'   used if `slice = FALSE`.
+#' @param percentage Numeric. Percentage number to split the predictor
+#'   distribution into. A value of 10 would split the predictor distribution by
+#'   10\% intervals. Only needed if `slice = TRUE`.
+#' @param slice Logical. `Default = FALSE`. Whether to calculate odds ratios for
+#'   fixed increment steps over the whole predictor distribution. See
+#'   `percentage` for setting the increment values.
+#' @param CI Numeric. Currently fixed to 95\% confidence interval level (2.5\% -
+#'   97.5\%). It should not be changed in a function call!
 #'
-#' @param pred Character. Predictor name for which to calculate
-#' the odds ratio.
+#' @details Currently supported functions: [mgcv::gam], [mgcv::gamm],
+#'   [gam::gam]. For [mgcv::gamm], the `model` input of [or_gam] needs to be the
+#'   `gam` output (e.g. `fit_gam$gam`).
 #'
-#' @param values Numeric vector of length two.
-#' Predictor values to estimate odds ratio from. Function is written to use the
-#' first provided value as the "lower" one, i.e. calculating the odds ratio
-#' 'from value1 to value2'. Only used if `slice = FALSE`.
-#'
-#' @param percentage Numeric. Percentage number to split the
-#' predictor distribution into.
-#' A value of 10 would split the predictor distribution by 10\% intervals.
-#' Only needed if `slice = TRUE`.
-#'
-#' @param slice Logical. `Default = FALSE`. Whether to calculate
-#' odds ratios for fixed increment steps over the whole predictor distribution.
-#' See `percentage` for setting the increment values.
-#'
-#' @param CI Numeric. Currently fixed to 95\% confidence interval level
-#' (2.5\% - 97.5\%).
-#' It should not be changed in a function call!
-#'
-#' @details Currently supported functions: [mgcv::gam],
-#' [mgcv::gamm], [gam::gam].
-#'
-#' @details For [mgcv::gamm], the `model` input of
-#' [or_gam] needs to be the `gam` output (e.g. `fit_gam$gam`).
-#'
-#' @return A data frame with (up to) eight columns. `perc1` and `perc2`
-#' are only returned if `slice = TRUE`:
+#' @return A data frame with (up to) eight columns. `perc1` and `perc2` are only
+#'   returned if `slice = TRUE`:
 #' \item{predictor}{Predictor name}
 #' \item{value1}{First value of odds ratio calculation}
 #' \item{value2}{Second value of odds ratio calculation}
@@ -60,21 +50,26 @@
 #' # load data (Source: ?mgcv::gam) and fit model
 #' library(mgcv)
 #' fit_gam <- gam(y ~ s(x0) + s(I(x1^2)) + s(x2) +
-#'                offset(x3) + x4, data = data_gam) # fit model
+#'   offset(x3) + x4, data = data_gam) # fit model
 #'
 #' # Calculate OR for specific increment step of continuous variable
-#' or_gam(data = data_gam, model = fit_gam, pred = "x2",
-#'        values = c(0.099, 0.198))
+#' or_gam(
+#'   data = data_gam, model = fit_gam, pred = "x2",
+#'   values = c(0.099, 0.198)
+#' )
 #'
 #' ## Calculate OR for change of indicator variable
-#' or_gam(data = data_gam, model = fit_gam, pred = "x4",
-#'        values = c("B", "D"))
+#' or_gam(
+#'   data = data_gam, model = fit_gam, pred = "x4",
+#'   values = c("B", "D")
+#' )
 #'
 #' ## Calculate ORs for percentage increments of predictor distribution
 #' ## (here: 20%)
-#' or_gam(data = data_gam, model = fit_gam, pred = "x2",
-#'        percentage = 20, slice = TRUE)
-#'
+#' or_gam(
+#'   data = data_gam, model = fit_gam, pred = "x2",
+#'   percentage = 20, slice = TRUE
+#' )
 #' @export
 or_gam <- function(data = NULL, model = NULL, pred = NULL, values = NULL,
                    percentage = NULL, slice = FALSE, CI = NULL) {
@@ -97,23 +92,25 @@ or_gam <- function(data = NULL, model = NULL, pred = NULL, values = NULL,
       range_v <- c(range_v, min(data[, pred]) + step * i)
     }
 
-    result <- data.frame(predictor = length(100 / percentage),
-                         value1 = numeric(length = 100 / percentage),
-                         value2 = numeric(length = 100 / percentage),
-                         perc1 = character(length = 100 / percentage),
-                         perc2 = character(length = 100 / percentage),
-                         oddsratio = numeric(length = 100 / percentage),
-                         CI_low = numeric(length = 100 / percentage),
-                         CI_high = numeric(length = 100 / percentage),
-                         stringsAsFactors = FALSE)
+    result <- tibble(
+      predictor = length(100 / percentage),
+      value1 = numeric(length = 100 / percentage),
+      value2 = numeric(length = 100 / percentage),
+      perc1 = character(length = 100 / percentage),
+      perc2 = character(length = 100 / percentage),
+      oddsratio = numeric(length = 100 / percentage),
+      CI_low = numeric(length = 100 / percentage),
+      CI_high = numeric(length = 100 / percentage)
+    )
 
     # apply OR calc for vector
     for (x in 1:(100 / percentage)) {
 
       # set all preds to their mean if they are numeric
       for (i in names_pred) {
-        if (is.numeric(data[[i]]))
+        if (is.numeric(data[[i]])) {
           data[[i]] <- mean(data[[i]])
+        }
       }
 
       # reduce to 1 row
@@ -125,7 +122,8 @@ or_gam <- function(data = NULL, model = NULL, pred = NULL, values = NULL,
       data[, pred] <- range_v[x]
       # calc log odds for value 1
       pred_gam1 <- as.numeric(predict(model, data,
-                                      type = "link", se.fit = TRUE))
+        type = "link", se.fit = TRUE
+      ))
       # calc 95% CI log odds (mean +- 2* stdev)
       pred_gam1_CI_low <- pred_gam1[1] - (2 * pred_gam1[2])
       pred_gam1_CI_high <- pred_gam1[1] + (2 * pred_gam1[2])
@@ -134,20 +132,21 @@ or_gam <- function(data = NULL, model = NULL, pred = NULL, values = NULL,
       data[, pred] <- range_v[x + 1]
       # calc log odds for value 2
       pred_gam2 <- as.numeric(predict(model, data,
-                                      type = "link", se.fit = TRUE))
+        type = "link", se.fit = TRUE
+      ))
       # calc 95% CI log odds (mean +- 2* stdev)
       pred_gam2_CI_low <- pred_gam2[1] - (2 * pred_gam2[2])
       pred_gam2_CI_high <- pred_gam2[1] + (2 * pred_gam2[2])
 
       result$predictor <- pred
       result$oddsratio[x] <- round(as.numeric(exp(pred_gam2[1] -
-                                                    pred_gam1[1])), 2)
+        pred_gam1[1])), 2)
       result$value1[x] <- round(range_v[x], 3)
       result$value2[x] <- round(range_v[x + 1], 3)
       result$CI_high[x] <- round(as.numeric(exp(pred_gam2_CI_low -
-                                                  pred_gam1_CI_low)), 2) # no mistake # nolint
+        pred_gam1_CI_low)), 2) # no mistake # nolint
       result$CI_low[x] <- round(as.numeric(exp(pred_gam2_CI_high -
-                                                 pred_gam1_CI_high)), 2) # no mistake # nolint
+        pred_gam1_CI_high)), 2) # no mistake # nolint
       result$perc1[x] <- percentage * x - percentage
       result$perc2[x] <- percentage * x
     }
@@ -161,8 +160,9 @@ or_gam <- function(data = NULL, model = NULL, pred = NULL, values = NULL,
 
   # set all preds to their mean if they are numeric
   for (i in names_pred) {
-    if (is.numeric(data[[i]]))
+    if (is.numeric(data[[i]])) {
       data[[i]] <- mean(data[[i]])
+    }
   }
 
   # reduce to 1 row
@@ -192,13 +192,14 @@ or_gam <- function(data = NULL, model = NULL, pred = NULL, values = NULL,
   odds_ratio_low <- as.numeric(exp(pred_gam2_CI_low - pred_gam1_CI_low), 2)
   odds_ratio_high <- as.numeric(exp(pred_gam2_CI_high - pred_gam1_CI_high), 2)
 
-  result <- data.frame(predictor = pred,
-                       value1 = values[1],
-                       value2 = values[2],
-                       oddsratio = odds_ratio,
-                       CI_low = odds_ratio_high, # no mistake
-                       CI_high = odds_ratio_low, # no mistake
-                       stringsAsFactors = FALSE)
+  result <- tibble(
+    predictor = pred,
+    value1 = values[1],
+    value2 = values[2],
+    oddsratio = odds_ratio,
+    CI_low = odds_ratio_high, # no mistake
+    CI_high = odds_ratio_low# no mistake
+  )
 
   # change col names
   colnames(result)[5] <- paste0("CI_low (2.5%)")
